==> 4.0.1.tar.gz: dde-dock/translations/dde-dock_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>DatetimePlugin</name>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="73"/>
        <source>MM/dd/yyyy ddd HH:mm:ss</source>
        <translation>MM/dd/llll ddd UU:mm:ss</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <location filename="../plugins/datetime/datetimewidget.cpp" line="35"/>
        <source>HH:mm</source>
        <translation>UU:mm</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="82"/>
        <source>Unknown device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="88"/>
        <source>Unknown volume</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DockSettings</name>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="19"/>
        <source>Fashion Mode</source>
        <translation>Modni način</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="20"/>
        <source>Efficient Mode</source>
        <translation>Učinkovit način</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="21"/>
        <source>Top</source>
        <translation>Vrh</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="22"/>
        <source>Bottom</source>
        <translation>Dno</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="23"/>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="24"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="25"/>
        <source>Large</source>
        <translation>Veliko</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="26"/>
        <source>Medium</source>
        <translation>Srednje</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="27"/>
        <source>Small</source>
        <translation>Majhno</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="28"/>
        <source>Keep Shown</source>
        <translation>Ohrani prikazano</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="29"/>
        <source>Keep Hidden</source>
        <translation>Ohrani skrito</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="30"/>
        <source>Smart Hide</source>
        <translation>Pametno skrivanje</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="64"/>
        <source>Mode</source>
        <translation>Način</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="72"/>
        <source>Location</source>
        <translation>Položaj</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="79"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="86"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <location filename="../frame/item/launcheritem.cpp" line="17"/>
        <source>Launcher</source>
        <translation>Zaganjalnik</translation>
    </message>
</context>
<context>
    <name>PopupControlWidget</name>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="70"/>
        <source>Empty</source>
        <translation>Prazno</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="70"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="75"/>
        <source>This action cannot be restored</source>
        <translation>Tega dejanja se ne da preklicati</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="77"/>
        <source>Are you sure to empty 1 item ?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="79"/>
        <source>Are you sure to empty %1 items ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="28"/>
        <source>Device</source>
        <translation>Naprava</translation>
    </message>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="47"/>
        <source>Application</source>
        <translation>Program</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="17"/>
        <source>Run</source>
        <translation>Zaženi</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="18"/>
        <source>Empty</source>
        <translation>Prazno</translation>
    </message>
</context>
<context>
    <name>WiredItem</name>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="36"/>
        <source>Unknow</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="41"/>
        <source>Disconnect</source>
        <translation>Prekini</translation>
    </message>
</context>
<context>
    <name>WirelessApplet</name>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="35"/>
        <source>Auto-connect</source>
        <translation>Samodejno poveži</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="42"/>
        <source>Connect</source>
        <translation>Poveži</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="136"/>
        <source>Wireless Network</source>
        <translation>Brezžično omrežje</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="138"/>
        <source>Wireless Network %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="367"/>
        <source>Password required to connect to &lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt;</source>
        <translation>Za povezavo z/s &lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt; je potrebno geslo</translation>
    </message>
</context>
</TS>

==> 4.0.2.tar.gz: dde-dock/translations/dde-dock_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>DatetimePlugin</name>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="73"/>
        <source> HH:mm:ss</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <location filename="../plugins/datetime/datetimewidget.cpp" line="42"/>
        <source>HH:mm</source>
        <translation>UU:mm</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="86"/>
        <source>Unknown device</source>
        <translation>Neznana naprava</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="92"/>
        <source>Unknown volume</source>
        <translation>Neznan prostor</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="14"/>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
</context>
<context>
    <name>DockSettings</name>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="20"/>
        <source>Fashion Mode</source>
        <translation>Modni način</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="21"/>
        <source>Efficient Mode</source>
        <translation>Učinkovit način</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="22"/>
        <source>Top</source>
        <translation>Vrh</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="23"/>
        <source>Bottom</source>
        <translation>Dno</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="24"/>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="25"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="26"/>
        <source>Large</source>
        <translation>Veliko</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="27"/>
        <source>Medium</source>
        <translation>Srednje</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="28"/>
        <source>Small</source>
        <translation>Majhno</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="29"/>
        <source>Keep Shown</source>
        <translation>Ohrani prikazano</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="30"/>
        <source>Keep Hidden</source>
        <translation>Ohrani skrito</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="31"/>
        <source>Smart Hide</source>
        <translation>Pametno skrivanje</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="65"/>
        <source>Mode</source>
        <translation>Način</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="73"/>
        <source>Location</source>
        <translation>Položaj</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="80"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="87"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <location filename="../frame/item/launcheritem.cpp" line="17"/>
        <source>Launcher</source>
        <translation>Zaganjalnik</translation>
    </message>
</context>
<context>
    <name>PopupControlWidget</name>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="68"/>
        <source>Empty</source>
        <translation>Prazno</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="68"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="73"/>
        <source>This action cannot be restored</source>
        <translation>Tega dejanja se ne da razveljaviti</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="75"/>
        <source>Are you sure to empty 1 item ?</source>
        <translation>Se prepričani, da želite izprazniti 1 datoteko?</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="77"/>
        <source>Are you sure to empty %1 items ?</source>
        <translation>Se prepričani, da želite izprazniti %1 datotek?</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="47"/>
        <source>Shut down</source>
        <translation>Zaustavitev sistema</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="28"/>
        <source>Device</source>
        <translation>Naprava</translation>
    </message>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="47"/>
        <source>Application</source>
        <translation>Program</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="17"/>
        <source>Run</source>
        <translation>Zaženi</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="18"/>
        <source>Empty</source>
        <translation>Prazno</translation>
    </message>
</context>
<context>
    <name>WiredItem</name>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="36"/>
        <source>Unknow</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="41"/>
        <source>Disconnect</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="51"/>
        <source>Wired connection %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="35"/>
        <source>Auto-connect</source>
        <translation>Samodejno poveži</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="42"/>
        <source>Connect</source>
        <translation>Poveži</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="143"/>
        <source>Wireless Network</source>
        <translation>Brezžično omrežje</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="145"/>
        <source>Wireless Network %1</source>
        <translation>Brezžično omrežje %1</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="370"/>
        <source>Password required to connect to &lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt;</source>
        <translation>Za povezavo z/s &lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt; je potrebno geslo</translation>
    </message>
</context>
</TS>
